[![DOI](https://zenodo.org/badge/576188110.svg)](https://zenodo.org/badge/latestdoi/576188110)\
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)\
![example workflow](https://github.com/baler-compressor/baler/actions/workflows/test_and_lint.yaml/badge.svg)
![example workflow](https://github.com/baler-compressor/baler/actions/workflows/docker.yaml/badge.svg)

# Introduction
Baler is a tool used to test the feasibility of compressing different types of scientific data using machine learning-based autoencoders. Baler provides you with an easy way to:
1. Train a machine learning model on your data
2. Compress your data with that model. This will also save the compressed file and model
3. Decompress the file using the model at a later time



# Getting Started #
Baler now exists as a *pip package* which you can install through:
```console
pip install baler-compressor
```

For examples how to use Baler we recommend following the tutorial from our baler-demo repository: https://github.com/baler-collaboration/baler-demo



# Contributing
If you wish to contribute, please see the [contribution guidelines](https://github.com/baler-collaboration/baler/blob/main/docs/CONTRIBUTING.md).
